import { ref, toRefs, onMounted, openBlock, createElementBlock, normalizeStyle, unref, renderSlot } from 'vue';

var script = {
  __name: 'vue3-draggable-div',
  props: {
    width: {
      type: Number,
      default: '200px'
    },
    height: {
      type: Number,
      default: '200px'
    }
  },
  emits: ['on-begin-drag,on-dragging,on-end-drag'],

  setup(__props, _ref) {
    let {
      emit: emits
    } = _ref;
    const props = __props;
    const elToDrag = ref(null);
    const {
      width,
      height
    } = toRefs(props);
    onMounted(() => {
      dragElement(elToDrag.value);
    }); //推拽

    function dragElement(elmnt) {
      var pos1 = 0,
          pos2 = 0,
          pos3 = 0,
          pos4 = 0;

      if (document.getElementById(elmnt.id + 'header')) {
        // if present, the header is where you move the DIV from:
        document.getElementById(elmnt.id + 'header').onmousedown = dragMouseDown;
      } else {
        // otherwise, move the DIV from anywhere inside the DIV:
        elmnt.onmousedown = dragMouseDown;
      }

      function dragMouseDown(e) {
        e = e || window.event;
        e.preventDefault();
        emits('on-begin-drag'); // get the mouse cursor position at startup:

        pos3 = e.clientX;
        pos4 = e.clientY;
        document.onmouseup = closeDragElement; // call a function whenever the cursor moves:

        document.onmousemove = elementDrag;
      }

      function elementDrag(e) {
        e = e || window.event;
        e.preventDefault(); // calculate the new cursor position:

        pos1 = pos3 - e.clientX;
        pos2 = pos4 - e.clientY;
        pos3 = e.clientX;
        pos4 = e.clientY; // set the element's new position:

        elmnt.style.top = elmnt.offsetTop - pos2 + 'px';
        elmnt.style.left = elmnt.offsetLeft - pos1 + 'px';
        emits('on-dragging');
      }

      function closeDragElement() {
        // stop moving when mouse button is released:
        document.onmouseup = null;
        document.onmousemove = null;
        emits('on-end-drag');
      }
    }

    return (_ctx, _cache) => {
      return openBlock(), createElementBlock("div", {
        style: normalizeStyle({
          width: unref(width),
          height: unref(height),
          position: 'absolute',
          zIndex: 50,
          cursor: 'move'
        }),
        ref_key: "elToDrag",
        ref: elToDrag
      }, [renderSlot(_ctx.$slots, "default")], 4);
    };
  }

};

// Import vue component
// IIFE injects install function into component, allowing component
// to be registered via Vue.use() as well as Vue.component(),

var entry_esm = /*#__PURE__*/(() => {
  // Get component instance
  const installable = script; // Attach install function executed by Vue.use()

  installable.install = app => {
    app.component('Vue3DraggableDiv', installable);
  };

  return installable;
})(); // It's possible to expose named exports when writing components that can
// also be used as directives, etc. - eg. import { RollupDemoDirective } from 'rollup-demo';
// export const RollupDemoDirective = directive;

export { entry_esm as default };
